<?PHP

/**  
  *  The nature of this modification requires delivery as a patch instead of
  *  a module.  This is because (currently) authentication happens in the base
  *  User() class, so we have to modify that file directly.  However, 
  *  uninstallation of a module deletes all modified files, which effectively
  *  kills the SugarCRM installation.  ... Therefore we give you this patch!
  *
  *  It makes uses of the fact that manifest.php (currently) gets require'd 
  *  during installation, which allows us to run code.  But since it only 
  *  gets require'd during the preparation stage and not the final commit stage, 
  *  we cheat a little and assume if you get to that point, then you're going
  *  all the way.
  *
  *  Future releases will hopefully allow for normal module delivery.
  */

// manifest file for information regarding application of new code
$manifest = array(
    // only install on the following regex sugar versions (if empty, no check)
    'acceptable_sugar_versions' => array('3.5.1c'),

    // name of new code
    'name' => 'WiKID Authentication',

    // description of new code
    'description' => 'A modification to the User class to support WiKID Strong Authentication',

    // author of new code
    'author' => 'ghaygood@wikidsystems.com',

    // date published
    'published_date' => '2005/11/05',

    // version of code
    'version' => '1.0.1',

    // type of code (valid choices are: full, langpack, module, patch, theme )
    'type' => 'patch',

    // icon for displaying in UI (path to graphic contained within zip package)
    'icon' => '',
);

$installdefs = array(
    'id'=> 'auth_wikid',
    'copy' => array(
        array('from' => '<basepath>/modules/Users',
              'to'   => 'modules/Users',
        ),
    ),

    'custom_fields' => array(
        //will be referenced as use_auth_wikid_c - _c indicates a custom field
        //current types are text,textarea,double,float,int,date,bool,enum (select), relate
        array(  'name'=>'use_auth_wikid',
                'label'=>'Use WiKID Auth?',
                'type'=>'bool',
                'max_size'=>1,
                'require_option'=>'optional',
                'default_value'=>'off',
                'ext1'=>'',
                'ext2'=>'',
                'ext3'=>'',
                'audited'=>0,
                'module'=>'Users',
        ),
        array(  'name'=>'auth_wikid_registered',
                'label'=>'WiKID Client Registered?',
                'type'=>'bool',
                'max_size'=>1,
                'require_option'=>'optional',
                'default_value'=>'off',
                'ext1'=>'',
                'ext2'=>'',
                'ext3'=>'',
                'audited'=>0,
                'module'=>'Users',
        ),
    ),
    
);

if ($_REQUEST['action'] == 'UpgradeWizard_prepare' && $_REQUEST['mode'] == 'Install') {

    // borrowed from ModuleInstall/ModuleInstaller.php for patch'ing
    $mod =& new User();
    $installed = true;
    foreach ($installdefs['custom_fields'] as $field) {
        $mod->custom_fields->addField($field['name'], $field['label'], $field['type'],
                                        $field['max_size'], $field['require_option'], 
                                        $field['default_value'], $field['ext1'], 
                                        $field['ext2'], $field['ext3'], 
                                        $field['audited']);
    }

    global $sugar_config;
    global $mod_strings;

    $sugar_config['wikid_auth'] =
      array(
        'enabled'           => true,
        'servercode'        => '127000000001',
        'server_host'       => '127.0.0.1',
        'server_port'       => 8388,
        'client_cert_file'  => 'issued-client-cert-and-key.pem',
        'client_key_pass'   => 'changeme',
        'ca_cert_file'      => 'modules/Users/Auth_WiKID-ca.pem',
      );

    ksort( $sugar_config );

    if( write_array_to_file( "sugar_config", $sugar_config, "config.php" ) ){
        $config_check = $mod_strings['MSG_CONFIG_FILE_REBUILD_SUCCESS'];
    }
    else {
        $config_check = $mod_strings['MSG_CONFIG_FILE_REBUILD_FAILED'];
    }
    echo $config_check;

}

?>
